X-Original-To: pgsql-performance-postgresql.org@localhost.postgresql.org Received: from localhost (av.hub.org [200.46.204.144]) by svr1.postgresql.org (Postfix) with ESMTP id E52FBD83A5 for ; Thu, 22 Sep 2005 22:41:36 -0300 (ADT) Received: from svr1.postgresql.org ([200.46.204.71]) by localhost (av.hub.org [200.46.204.144]) (amavisd-new, port 10024) with ESMTP id 89332-03 for ; Fri, 23 Sep 2005 01:41:31 +0000 (GMT) Received: from BAYC1-PASMTP04.bayc1.hotmail.com (bayc1-pasmtp04.bayc1.hotmail.com [65.54.191.164]) by svr1.postgresql.org (Postfix) with ESMTP id 8C14FD81D2 for ; Thu, 22 Sep 2005 22:41:32 -0300 (ADT) Message-ID: X-Originating-IP: [70.50.100.93] X-Originating-Email: [pelletier_32@sympatico.ca] Received: from JP ([70.50.100.93]) by BAYC1-PASMTP04.bayc1.hotmail.com over TLS secured channel with Microsoft SMTPSVC(6.0.3790.1830); Thu, 22 Sep 2005 18:41:04 -0700 Message-ID: <006201c5bfdf$f0c71bc0$6501a8c0@JP> From: "Jean-Pierre Pelletier" To: , Cc: "John Arbash Meinel" References: <433326A6.8010708@arbash-meinel.com> <200509221519.05555.josh@agliodbs.com> Subject: Re: Queries 15 times slower on 8.1 beta 2 than on 8.0 Date: Thu, 22 Sep 2005 21:41:37 -0400 MIME-Version: 1.0 Content-Type: text/plain; format=flowed; charset="iso-8859-1"; reply-type=original Content-Transfer-Encoding: 7bit X-Priority: 3 X-MSMail-Priority: Normal X-Mailer: Microsoft Outlook Express 6.00.2900.2670 X-MimeOLE: Produced By Microsoft MimeOLE V6.00.2900.2670 X-OriginalArrivalTime: 23 Sep 2005 01:41:04.0559 (UTC) FILETIME=[DC5C83F0:01C5BFDF] X-Virus-Scanned: by amavisd-new at hub.org X-Spam-Status: No, hits=0.518 required=5 tests=[AWL=0.002, FROM_ENDS_IN_NUMS=0.516, MSGID_FROM_MTA_HEADER=0] X-Spam-Level: X-Archive-Number: 200509/270 X-Sequence-Number: 14578 Explain analyze on my 8.0.1 installation does report the time for slower queries but for this small query it reports 0.000 ms ----- Original Message ----- From: "Josh Berkus" To: Cc: "Jean-Pierre Pelletier" ; "John Arbash Meinel" Sent: Thursday, September 22, 2005 6:19 PM Subject: Re: [PERFORM] Queries 15 times slower on 8.1 beta 2 than on 8.0 > Jean-Pierre, > > First off, you're on Windows? > >> " -> Seq Scan on price p (cost=0.00..11317.75 rows=581475 width=4) >> (actual time=0.004..1143.720 rows=581475 loops=1)" > > Well, this is your pain point. Can we see the index scan plan on 8.1? > Given that it's *expecting* only one row, I can't understand why it's > using a seq scan ... > >> "Nested Loop Left Join (cost=0.00..11.02 rows=1 width=0) (actual >> time=0.000..0.000 rows=1 loops=1)" >> " -> Nested Loop Left Join (cost=0.00..5.48 rows=1 width=4) (actual >> time=0.000..0.000 rows=1 loops=1)" >> "Total runtime: 0.000 ms" > > Feh, this looks like the "windows does not report times" bug, which makes > it hard to compare ... > > -- > --Josh > > Josh Berkus > Aglio Database Solutions > San Francisco > > ---------------------------(end of broadcast)--------------------------- > TIP 3: Have you checked our extensive FAQ? > > http://www.postgresql.org/docs/faq